Package: basilisk.utils
Version: 1.24.0
Date: 2025-11-09
Title: Centralized Conda Installation for Bioconductor Packages
Authors@R: c(person("Aaron", "Lun", role=c("aut", "cre", "cph"),
        email="infinite.monkeys.with.keyboards@gmail.com"))
Imports: utils, methods, tools, dir.expiry
Suggests: knitr, rmarkdown, BiocStyle, testthat
biocViews: Infrastructure
Description: Provides a centralized conda installation for use by other
        Bioconductor packages. If conda is not already available on the
        system, it is downloaded and installed from the Miniforge
        project; otherwise, no action is performed. Historically, this
        package was used to provide a Python installation for basilisk,
        hence the name.
License: GPL-3
RoxygenNote: 7.3.2
VignetteBuilder: knitr
Encoding: UTF-8
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 12:51:52 UTC
RemoteUrl: https://github.com/bioc/basilisk.utils
RemoteRef: RELEASE_3_23
RemoteSha: 19a6b8f6b46a916fbaa3171edab3a5f3b2bf5776
NeedsCompilation: no
Packaged: 2026-04-29 18:10:57 UTC; root
Author: Aaron Lun [aut, cre, cph]
Maintainer: Aaron Lun <infinite.monkeys.with.keyboards@gmail.com>
Built: R 4.6.0; ; 2026-04-29 19:03:33 UTC; unix
