Package: basilisk.utils
Version: 1.24.0
Date: 2025-11-09
Title: Centralized Conda Installation for Bioconductor Packages
Authors@R: c(person("Aaron", "Lun", role=c("aut", "cre", "cph"),
        email="infinite.monkeys.with.keyboards@gmail.com"))
Imports: utils, methods, tools, dir.expiry
Suggests: knitr, rmarkdown, BiocStyle, testthat
biocViews: Infrastructure
Description: 
    Provides a centralized conda installation for use by other Bioconductor packages.
    If conda is not already available on the system, it is downloaded and installed from the Miniforge project; otherwise, no action is performed.
    Historically, this package was used to provide a Python installation for basilisk, hence the name.
License: GPL-3
RoxygenNote: 7.3.2
VignetteBuilder: knitr
Encoding: UTF-8
git_url: https://git.bioconductor.org/packages/basilisk.utils
git_branch: RELEASE_3_23
git_last_commit: 19a6b8f
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 20:44:27 UTC; biocbuild
Author: Aaron Lun [aut, cre, cph]
Maintainer: Aaron Lun <infinite.monkeys.with.keyboards@gmail.com>
