# Generated by roxygen2: do not edit by hand

export(condaBinary)
export(configureEnvironments)
export(createEnvironment)
export(defaultCacheDirectory)
export(defaultCommand)
export(defaultDownloadVersion)
export(defaultMinimumVersion)
export(download)
export(find)
export(pythonBinary)
import(dir.expiry)
importFrom(methods,is)
importFrom(tools,R_user_dir)
importFrom(utils,download.file)
